@@ -25,7 +25,8 @@ L<FP::Array> -- definition of most functions used here
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
