@@ -28,7 +28,8 @@ wrappers are all uppercase, and "-" is replaced with "_".
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
